# RAIMAD

RAIMAD Astronomical Instrument MAsk Designer

![RAIMAD banner](img/raimad-banner.png)

This is a work-in-progress project. Documentation coming soon!

## License

RAIMAD is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, version 3 of the License only.

RAIMAD is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
RAIMAD. If not, see <https://www.gnu.org/licenses/>. 

---

Copyright (c) 2024, maybetree.

